@@ -1,4 +1,5 @@
 #!/bin/bash
+set -e
 
 # Report an error if the generated sample environments are not in sync with
 # the current configuration and templates.
@@ -17,7 +18,7 @@ cd $tmpdir
 
 file_list=$(find environments -type f)
 for f in $file_list; do
-    if ! $base/tools/yaml-diff.py $f $base/$f; then
+    if ! diff -q $f $base/$f; then
         echo "ERROR: $base/$f is not up to date"
         diff $f $base/$f
         retval=1
